aboutsummaryrefslogtreecommitdiff
path: root/examples/graph_squeezenet.cpp
diff options
context:
space:
mode:
authorIsabella Gottardi <isabella.gottardi@arm.com>2017-11-03 14:39:44 +0000
committerAnthony Barbier <anthony.barbier@arm.com>2018-11-02 16:35:24 +0000
commit97988a4b3ef0f840432daf95b6e4b2ad7e5feefd (patch)
tree4e6200486851ac544becd16da41c3de647debce6 /examples/graph_squeezenet.cpp
parentac85acf5937aa22a7fc4eb9dc8c8c31045e15d6d (diff)
downloadComputeLibrary-97988a4b3ef0f840432daf95b6e4b2ad7e5feefd.tar.gz
COMPMID-657 - Add PPMAccessor and TopNPredictionsAccessor to SqueezeNet
Change-Id: I8baaee68b82e200a4829c3fc6c60dd211c06e14f Reviewed-on: http://mpd-gerrit.cambridge.arm.com/94534 Tested-by: Kaizen <jeremy.johnson+kaizengerrit@arm.com> Reviewed-by: Gian Marco Iodice <gianmarco.iodice@arm.com> Reviewed-by: Anthony Barbier <anthony.barbier@arm.com>
Diffstat (limited to 'examples/graph_squeezenet.cpp')
-rw-r--r--examples/graph_squeezenet.cpp107
1 files changed, 50 insertions, 57 deletions
diff --git a/examples/graph_squeezenet.cpp b/examples/graph_squeezenet.cpp
index a1a7b8619e..195fe0addb 100644
--- a/examples/graph_squeezenet.cpp
+++ b/examples/graph_squeezenet.cpp
@@ -43,43 +43,22 @@ using namespace arm_compute::graph;
using namespace arm_compute::graph_utils;
using namespace arm_compute::logging;
-/** Generates appropriate accessor according to the specified path
- *
- * @note If path is empty will generate a DummyAccessor else will generate a NumPyBinLoader
- *
- * @param path Path to the data files
- * @param data_file Relative path to the data files from path
- *
- * @return An appropriate tensor accessor
- */
-std::unique_ptr<ITensorAccessor> get_accessor(const std::string &path, const std::string &data_file)
-{
- if(path.empty())
- {
- return arm_compute::support::cpp14::make_unique<DummyAccessor>();
- }
- else
- {
- return arm_compute::support::cpp14::make_unique<NumPyBinLoader>(path + data_file);
- }
-}
-
BranchLayer get_expand_fire_node(const std::string &data_path, std::string &&param_path, unsigned int expand1_filt, unsigned int expand3_filt)
{
std::string total_path = "/cnn_data/squeezenet_v1.0_model/" + param_path + "_";
SubGraph i_a;
i_a << ConvolutionLayer(
1U, 1U, expand1_filt,
- get_accessor(data_path, total_path + "expand1x1_w.npy"),
- get_accessor(data_path, total_path + "expand1x1_b.npy"),
+ get_weights_accessor(data_path, total_path + "expand1x1_w.npy"),
+ get_weights_accessor(data_path, total_path + "expand1x1_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU));
SubGraph i_b;
i_b << ConvolutionLayer(
3U, 3U, expand3_filt,
- get_accessor(data_path, total_path + "expand3x3_w.npy"),
- get_accessor(data_path, total_path + "expand3x3_b.npy"),
+ get_weights_accessor(data_path, total_path + "expand3x3_w.npy"),
+ get_weights_accessor(data_path, total_path + "expand3x3_b.npy"),
PadStrideInfo(1, 1, 1, 1))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU));
@@ -89,32 +68,44 @@ BranchLayer get_expand_fire_node(const std::string &data_path, std::string &&par
/** Example demonstrating how to implement Squeezenet's network using the Compute Library's graph API
*
* @param[in] argc Number of arguments
* @param[in] argv Arguments ( [optional] Path to the weights folder, [optional] batches )
*/
void main_graph_squeezenet(int argc, const char **argv)
{
- std::string data_path; /** Path to the trainable data */
- unsigned int batches = 4; /** Number of batches */
+ std::string data_path; /* Path to the trainable data */
+ std::string image; /* Image data */
+ std::string label; /* Label data */
+
+ constexpr float mean_r = 122.68f; /* Mean value to subtract from red channel */
+ constexpr float mean_g = 116.67f; /* Mean value to subtract from green channel */
+ constexpr float mean_b = 104.01f; /* Mean value to subtract from blue channel */
// Parse arguments
if(argc < 2)
{
// Print help
- std::cout << "Usage: " << argv[0] << " [path_to_data] [batches]\n\n";
+ std::cout << "Usage: " << argv[0] << " [path_to_data] [image] [labels]\n\n";
std::cout << "No data folder provided: using random values\n\n";
}
else if(argc == 2)
{
//Do something with argv[1]
data_path = argv[1];
- std::cout << "Usage: " << argv[0] << " [path_to_data] [batches]\n\n";
- std::cout << "No number of batches where specified, thus will use the default : " << batches << "\n\n";
+ std::cout << "Usage: " << argv[0] << " " << argv[1] << " [image] [labels]\n\n";
+ std::cout << "No image provided: using random values\n";
+ }
+ else if(argc == 3)
+ {
+ data_path = argv[1];
+ image = argv[2];
+ std::cout << "Usage: " << argv[0] << " " << argv[1] << " " << argv[2] << " [labels]\n\n";
+ std::cout << "No text file with labels provided: skipping output accessor\n";
}
else
{
- //Do something with argv[1] and argv[2]
data_path = argv[1];
- batches = std::strtol(argv[2], nullptr, 0);
+ image = argv[2];
+ label = argv[3];
}
// Check if OpenCL is available and initialize the scheduler
@@ -126,81 +117,83 @@ void main_graph_squeezenet(int argc, const char **argv)
Graph graph;
graph << TargetHint::OPENCL
- << Tensor(TensorInfo(TensorShape(224U, 224U, 3U, batches), 1, DataType::F32), DummyAccessor())
+ << Tensor(TensorInfo(TensorShape(224U, 224U, 3U, 1U), 1, DataType::F32),
+ get_input_accessor(image, mean_r, mean_g, mean_b))
<< ConvolutionLayer(
7U, 7U, 96U,
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/conv1_w.npy"),
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/conv1_b.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/conv1_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/conv1_b.npy"),
PadStrideInfo(2, 2, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< PoolingLayer(PoolingLayerInfo(PoolingType::MAX, 3, PadStrideInfo(2, 2, 0, 0, DimensionRoundingType::CEIL)))
<< ConvolutionLayer(
1U, 1U, 16U,
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire2_squeeze1x1_w.npy"),
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire2_squeeze1x1_b.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire2_squeeze1x1_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire2_squeeze1x1_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< get_expand_fire_node(data_path, "fire2", 64U, 64U)
<< ConvolutionLayer(
1U, 1U, 16U,
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire3_squeeze1x1_w.npy"),
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire3_squeeze1x1_b.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire3_squeeze1x1_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire3_squeeze1x1_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< get_expand_fire_node(data_path, "fire3", 64U, 64U)
<< ConvolutionLayer(
1U, 1U, 32U,
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire4_squeeze1x1_w.npy"),
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire4_squeeze1x1_b.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire4_squeeze1x1_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire4_squeeze1x1_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< get_expand_fire_node(data_path, "fire4", 128U, 128U)
<< PoolingLayer(PoolingLayerInfo(PoolingType::MAX, 3, PadStrideInfo(2, 2, 0, 0, DimensionRoundingType::CEIL)))
<< ConvolutionLayer(
1U, 1U, 32U,
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire5_squeeze1x1_w.npy"),
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire5_squeeze1x1_b.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire5_squeeze1x1_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire5_squeeze1x1_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< get_expand_fire_node(data_path, "fire5", 128U, 128U)
<< ConvolutionLayer(
1U, 1U, 48U,
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire6_squeeze1x1_w.npy"),
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire6_squeeze1x1_b.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire6_squeeze1x1_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire6_squeeze1x1_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< get_expand_fire_node(data_path, "fire6", 192U, 192U)
<< ConvolutionLayer(
1U, 1U, 48U,
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire7_squeeze1x1_w.npy"),
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire7_squeeze1x1_b.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire7_squeeze1x1_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire7_squeeze1x1_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< get_expand_fire_node(data_path, "fire7", 192U, 192U)
<< ConvolutionLayer(
1U, 1U, 64U,
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire8_squeeze1x1_w.npy"),
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire8_squeeze1x1_b.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire8_squeeze1x1_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire8_squeeze1x1_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< get_expand_fire_node(data_path, "fire8", 256U, 256U)
<< PoolingLayer(PoolingLayerInfo(PoolingType::MAX, 3, PadStrideInfo(2, 2, 0, 0, DimensionRoundingType::CEIL)))
<< ConvolutionLayer(
1U, 1U, 64U,
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire9_squeeze1x1_w.npy"),
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire9_squeeze1x1_b.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire9_squeeze1x1_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/fire9_squeeze1x1_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< get_expand_fire_node(data_path, "fire9", 256U, 256U)
<< ConvolutionLayer(
1U, 1U, 1000U,
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/conv10_w.npy"),
- get_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/conv10_b.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/conv10_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/squeezenet_v1.0_model/conv10_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< PoolingLayer(PoolingLayerInfo(PoolingType::AVG, 13, PadStrideInfo(1, 1, 0, 0, DimensionRoundingType::CEIL)))
+ << FlattenLayer()
<< SoftmaxLayer()
- << Tensor(DummyAccessor());
+ << Tensor(get_output_accessor(label, 5));
graph.run();
}
@@ -208,9 +201,9 @@ void main_graph_squeezenet(int argc, const char **argv)
/** Main program for Squeezenet v1.0
*
* @param[in] argc Number of arguments
* @param[in] argv Arguments ( [optional] Path to the weights folder, [optional] batches )
*/
int main(int argc, const char **argv)
{
return arm_compute::utils::run_example(argc, argv, main_graph_squeezenet);
-}
+} \ No newline at end of file
@@ -89,32 +68,44 @@ BranchLayer get_expand_fire_node(const std::string &data_path, std::string &&par
*
* @param[in] argc Number of arguments
- * @param[in] argv Arguments ( [optional] Path to the weights folder, [optional] batches )
+ * @param[in] argv Arguments ( [optional] Path to the weights folder, [optional] image, [optional] labels )
*/
void main_graph_squeezenet(int argc, const char **argv)
@@ -208,9 +201,9 @@ void main_graph_squeezenet(int argc, const char **argv)
*
* @param[in] argc Number of arguments
- * @param[in] argv Arguments ( [optional] Path to the weights folder, [optional] batches )
+ * @param[in] argv Arguments ( [optional] Path to the weights folder, [optional] image, [optional] labels )
*/
int main(int argc, const char **argv)